part of leadlinkopenapi;

class APIUser {

  // 添加普通用户建档
  static void createUserInfo(String mobile,String password,String nickName,int userId,Function() onSucc, Function(String) onFail) async {

    try {

      var queryBuider = QueryBuilder<UserType>(UserType())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('name', 'normal');

      var resp = await queryBuider.query();
      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      ParseObject userType = resp.results.first;

      ParseObject user  = ParseObject('Users');
      user['mobile']    = mobile ?? '';
      user['salt']      = APIUtil.encrypted(randomAlpha(4) + password + randomAlpha(4));
      user['nickName']  = nickName ?? '';
      user['userType']  = userType;
      user['isActive']  = true;
      user['remark']    = nickName;
      user['userId']    = userId;

      await user.save();
      if(onSucc !=null) onSucc();

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }


  // 更新用户密码
  static void updateUserSalt(String mobile,String password,{Function() onSucc, Function(String) onFail}) async {

    try {

      var queryBuider = QueryBuilder<Users>(Users())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('mobile', mobile);

      var resp = await queryBuider.query();
      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      ParseObject user = resp.results.first;
      if(user == null) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      user['salt'] = APIUtil.encrypted(randomAlpha(4) + password + randomAlpha(4));
      await user.save();
      if(onSucc !=null) onSucc();

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }


  // 获取当前用户信息
  static void currentUserInfo({Function(Users user) onSucc, Function(String) onFail}) async {

    SharedPreferences prefs = await SharedPreferences.getInstance();
    int userId = prefs.getInt(APITip.spKeyUserId) ?? 0 ;

    if(userId == 0){
      if(onFail != null) onFail(APITip.apiNoLogin);
      return;
    }

    try {

      var queryBuider = QueryBuilder<Users>(Users())
      ..whereNotEqualTo('isActive', false)
      ..includeObject(['userType'])
      ..whereEqualTo('userId', userId);

      var resp = await queryBuider.query();
      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(resp.results.length == 0) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      Users user = resp.results.first;
      if(onSucc !=null) onSucc(user);


    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }

  // 所有用户信息
  static void getAllUserList({bool isDescending = true,Function(List<Users> userList) onSucc, Function(String) onFail}) async {

    try {

      var queryBuider = QueryBuilder<Users>(Users())
      ..whereNotEqualTo('isActive', false)
      ..includeObject(['userType']);

      if(isDescending == true){
        queryBuider.orderByDescending('userId');
      }
      else {
        queryBuider.orderByAscending('userId');
      }

      var resp = await queryBuider.query();
      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(onSucc !=null) onSucc(resp.results.cast<Users>());

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }


  // 修改用户昵称
  // 修改用户头像
  // 修改用户用户类型
}